@@ -26,12 +26,13 @@ Target::Target()
 	pictureSmall = NULL;
 	picture = NULL;
 	pictureBack = NULL;
+	listLoaded = false;
 }
 Target::~Target()
 {
+	freeFieldList ();
+	freeResources();
 	if(pictureSmall) delete pictureSmall;
-	if(picture) delete picture;
-	if(pictureBack) delete pictureBack;
 }
 
 void Target::freeResources()
@@ -43,13 +44,23 @@ void Target::freeResources()
 	pictureBack = NULL;
 }
 
+//bool operator<(const Entry &entry, const QString &family)
+//{
+//    return entry.familyName < family;
+//}
+//
+//bool operator<(const QString &family, const Entry &entry)
+
+
 void Target::freeFieldList()
 {
+	qDebug () << " free list for " << this->id;
 	TargetField * field;
 	foreach(field,this->fields) {
 		delete field;
 	}
 	fields.clear ();
+	listLoaded = false;
 }
 
 bool Target::existField (QString name) {
@@ -216,10 +227,28 @@ int DatabaseManager::nextId()
 	return ret;
 }
 
+void DatabaseManager::reset () {
+	bool ret = false;
+	if (db.isOpen()) {
+		QSqlQuery query;
+		ret |= query.exec("drop table id");
+		ret |= query.exec("drop table targets");
+		ret |= query.exec("drop table fieds");
+	}
+
+}
+
 void DatabaseManager::lock () {
 	initdb = false;
 }
 
+bool DatabaseManager::hasPassword() {
+	if (!opendb)
+		opendb = openDB();
+
+	return opendb && isInit () && hasSecretPhrase();
+}
+
 bool DatabaseManager::openDB(QString pas) {
 	initdb = false;
 
@@ -474,7 +503,6 @@ void DatabaseManager::decrypt (const QByteArray& a, QByteArray& b)
 	b = QByteArray ((char*)pout, l);
 }
 
-
 bool DatabaseManager::insertTarget(Target* target)
 {
 		qDebug() << "step 0" ;
@@ -544,7 +572,7 @@ QList<Target*> DatabaseManager::getTargets(QString filter)
 {
 	QList<Target*> result;
 
-	QSqlQuery query("select id, name, type from targets order by name");
+	QSqlQuery query("select id, name, type from targets");
 	//QSqlQuery query("select id, name, type, picture, pictureBack  from targets");
 	while (query.next()) {
 		Target * item = new Target();
@@ -589,14 +617,19 @@ bool DatabaseManager::deleteTarget(Target * target)
 	bool ret = false;
 	if (db.isOpen()) {
 		QSqlQuery query;
-		ret = query.prepare("delete from targets where id=:code");
+
+		ret = query.prepare("delete from fields where targetId=:code");
+		query.bindValue(":code", target->id);
+		ret = query.exec();
+
 		if (ret) {
-			qDebug () << "DELETE " << target->id;
+			ret = query.prepare("delete from targets where id=:code");
+			if (ret) {
+				qDebug () << "DELETE " << target->id;
 
-			query.bindValue(":code", target->id);
-			ret = query.exec();
-
-			delete target;
+				query.bindValue(":code", target->id);
+				ret = query.exec();
+			}
 		}
 	}
 
@@ -607,17 +640,23 @@ bool DatabaseManager::updateFields(Target* target)
 {
 	bool ret = false;
 	if (db.isOpen()) {
+
+		QSqlQuery query;
+		ret = query.prepare("delete from fields where targetId=:code");
+		query.bindValue(":code", target->id);
+		ret = query.exec();
+
 		for (int i = 0; i < target->fields.count(); i++) {
 			TargetField * field = target->fields[i];
 	
-			if (field->id == -1) {
+//			if (field->id == -1) {
 				field->targetId = target->id;
 				field->id = 0;
 				ret |= insertTargetField (field);
-			}
-			else {
-				ret |= updateTargetField (field);
-			}
+//			}
+//			else {
+//				ret |= updateTargetField (field);
+//			}
 		}
 	}
 	
@@ -789,8 +828,11 @@ bool DatabaseManager::insertTargetField(TargetField* field)
 
 void DatabaseManager::getFields(Target * target)
 {
-	
-	target->freeFieldList ();
+	if (target->listLoaded) return;
+
+	qDebug () << "get Fields for " << target->id;
+
+	//target->freeFieldList ();
 	
 	bool ret = false;
 	QSqlQuery query;
@@ -814,6 +856,8 @@ void DatabaseManager::getFields(Target * target)
 		}
 		target->fields.append(item);
 	}
+
+	target->listLoaded = true;
 }
 
 QImage * DatabaseManager::getPicture (Target * target) {
