@@ -22,6 +22,7 @@ public:
 
 	void resetF ();
 	void keyPressEvent(QKeyEvent* event);
+	void orientationChanged(int o);
 
 private slots:
 	void select(const QString& a);
@@ -36,7 +37,7 @@ private:
 	//QString current;
 	//QString repeat;
 	eWallet * parent;
-	
+	QDialogButtonBox* dlgBtnBox;
 	int NTimes;
 	bool isFirstTime;
 	QString newPassword;
