@@ -40,6 +40,9 @@ DatabaseManager * dbManager;
 
 eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 {
+	this->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+	connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
+
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 
 	ascSort = true;
@@ -58,6 +61,11 @@ eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 	//bool success = conn.connect("","", QString(MCE_SIGNAL_IF), QString(MCE_DISPLAY_SIG) , this, SLOT(listenInactivity(QString)));
 }
 
+void eWallet::orientationChanged(int o) {
+	if (isAskPassword) {
+		loginDialogDlg->orientationChanged (o);
+	}
+}
 void eWallet::showList () {
 	isAskPassword = false;
 
@@ -333,7 +341,7 @@ void eWallet::loadTypesAndFields () {
 }
 
 void eWallet::keyPressEvent(QKeyEvent* event) {
-	qDebug()<<"key pressed " << event->key();
+	//qDebug()<<"key pressed " << event->key();
 	
 	if (!isAskPassword) {
 		if (searchField->isHidden()) {
